@@ -12,23 +12,26 @@
 ## Licence:        GPL
 ###########################################################################
 
-import sys
-import random
-import time
-from time import strftime
-import math
-import array
-import string
+#import sys
+#import random
+#import time
+#from time import strftime
+#import math
+#import array
+#import string
 
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
 
-import ConfigParser
-import os, os.path
+#import ConfigParser
+#import os, os.path
 
 import dbus
 from dbus.mainloop.qt import DBusQtMainLoop
 
+
+
+
 import records #record data
 import data #own data
 
@@ -48,6 +51,11 @@ except:
 
 
 
+
+
+
+
+
 #GUIs
 from Ui_StartWindow import *
 from Ui_RecordWindow import *
@@ -60,13 +68,6 @@ from Ui_AskForKeepWindow import *
 from Ui_AdditionalInfoWindow import *
 
 
-#print "mylib is compiled:", mylib.IsCompiled()
-
-#arrTest=[1, 2, 3, 4, 5, 6, 7, 8]
-#arrTest2=[1, 2]
-#arrTest2=mylib.sleep_filter(arrTest)
-#print arrTest
-#print arrTest2
 
 ###########################################################################
 ## Main function
@@ -143,7 +144,7 @@ def main():
                      "but some functions will work slow as we have to fall back to the unoptimised python code!\" uint32:0 string:\"OK\""
             os.popen(cmd)
     else: #module is available but broken
-        print "Mylib could not be imported. Try removing/recompiling mylib.so"
+        print "Mylib could not be imported. It might be corrupted. You can get SleepAnalyser working by removing the file "+data.app_path+"lib/mylib.so."
         cmd="dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog " + \
                  "string:\"SleepAnalyser:\nSleepAnalyser could not load the module mylib.so\n" + \
                  "in "+data.app_path+"lib. It might be corrupted. Please check if there is a never version "+ \
@@ -249,7 +250,7 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
         ProcessData(False,  False)
         ProcessAlarm()
 
-        WriteIntoRecordFile()
+        WriteRecord()
 
 #        GraphLen=records.Index/data.arrXscale[data.Xscale]
 #        data.GraphStart=max(GraphLen-779, 0)
@@ -331,7 +332,7 @@ def InitMeasurement():
 
     CreateRecordFile(data.interval)
     GetFirstEntry()
-    WriteIntoRecordFile()
+    WriteRecord()
 
     GenerateGraphBitmap(RecordWindow, False)
 #    RecordWindow.UpdateScreen()
@@ -736,9 +737,9 @@ class frmRecordWindow(QMainWindow):
     def UpdateScreenStart(self): ##(Class RecordWindow)
 #        t=strftime("%d. %b. %Y %H:%M:%S", data.StartTime)
         t=strftime("%a. %x %X", data.StartTime)
-        self.ui.lblStarttime.setText("Start: "+t)
+#        self.ui.lblStarttime.setText("Start: "+t)
         self.ui.lblElapsedTime.setText("Elapsed time:")
-        self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser.png"))
+#        self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser.png"))
         self.ui.bStop.setIcon(QIcon(data.app_path+"img/"+"krec2.png"))
         self.ui.bStop.setText("Stop")
 
@@ -750,7 +751,7 @@ class frmRecordWindow(QMainWindow):
         else: #Do only recording, no alarm
             self.ui.lblAlarmTime.setText("Alarm time: (No Alarm set)")
 
-        self.ui.lblNote.setText("Note: ")
+#        self.ui.lblNote.setText("Note: ")
         self.UpdateScreen()
 
 
@@ -766,11 +767,13 @@ class frmRecordWindow(QMainWindow):
         if(data.run==True): #recording
             t=time.mktime(time.localtime())
             time_difference=t-data.StartTimeSec
-            d=time.strftime("%H:%M:%S", time.gmtime(time_difference))
-            self.ui.lblElapsedTime.setText("Elapsed time: "+d + " ("+str(records.Index)+" entries)")
+            d=time.strftime("%Hh %Mm", time.gmtime(time_difference))
+#            self.ui.lblElapsedTime.setText("Elapsed time: "+d + " ("+str(records.Index)+" entries)")
+            self.ui.lblElapsedTime.setText("Elapsed time: "+d)
         else: self.UpdateScreenStop()
 
-        self.ui.lblStatus2.setText("Status: "+data.Status)
+#        self.ui.lblStatus2.setText("Status: "+data.Status)
+        self.ui.lblStatus2.setText(data.Status)
 
         if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
         else: self.ui.bZoomIn.setEnabled(True)
@@ -789,7 +792,8 @@ class frmRecordWindow(QMainWindow):
 
     def UpdateScreenStop(self): ##(Class RecordWindow)
         self.ui.bStop.setText("Close")
-        self.ui.lblStatus2.setText("Status: "+data.Status)
+#        self.ui.lblStatus2.setText("Status: "+data.Status)
+        self.ui.lblStatus2.setText(data.Status)
 
 
 
@@ -877,7 +881,7 @@ class frmRecordWindow(QMainWindow):
         r=QInputDialog.getText(None,  "Add Note",  "Add a note to this record:\n(leave empty for no note)",  QLineEdit.Normal,  records.Note)
         if(r[1]==True): #OK pressed
             records.Note=unicode(r[0])
-            self.ui.lblNote.setText("Note: "+records.Note)
+#            self.ui.lblNote.setText("Note: "+records.Note)
             if(data.run==True): UpdateFileHeader() #rewrite log file (only do when recording is stopped!)
 
 
@@ -984,6 +988,7 @@ class frmViewWindow(QMainWindow):
         self.ui.lblStart.setText(str(day))
 #        self.ui.lblEnd.setText(str(d1)+" (Duration: "+d+str(diff)+")")
         self.ui.lblEnd.setText("Start: "+d0+", End: "+d1+", Duration: "+diff)
+        self.ui.lblEnd.setText(d0+" - "+d1+"   ("+diff+")")
 
 #        self.ui.lblNote.setText("Note: "+records.Note)
         self.ui.lblNote.setText(records.Note)
@@ -1286,7 +1291,8 @@ class frmViewWindow(QMainWindow):
             tmp=r[0]
             tmp=unicode(tmp)
             records.Note=tmp
-            self.ui.lblNote.setText("Note: "+records.Note)
+#            self.ui.lblNote.setText("Note: "+records.Note)
+            self.ui.lblNote.setText(records.Note)
             UpdateFileHeader() #rewrite log file (only do when recording is stopped!)
 
 
@@ -1379,6 +1385,11 @@ class frmConfigWindow(QMainWindow):
         QtCore.QObject.connect(self.ui.SlrDelayStart,SIGNAL("valueChanged(int)"),self.DelaySliderMoved)
         QtCore.QObject.connect(self.ui.SlrYscale,SIGNAL("valueChanged(int)"),self.YscaleSliderMoved)
 
+
+        QtCore.QObject.connect(self.ui.bOK, QtCore.SIGNAL("clicked()"), self.OK)
+#        QtCore.QObject.connect(self.ui.bCancel, QtCore.SIGNAL("clicked()"), self.Cancel)
+
+
         #Add styles to buttons
         self.ui.bEditUserName.setStyleSheet(data.UIStyle)
         self.ui.SlrDelayStart.setStyleSheet(data.UIStyle)
@@ -1408,24 +1419,49 @@ class frmConfigWindow(QMainWindow):
         self.ui.SlrYscale.setValue(int(data.Yscale))
 
 
+
+#    def Cancel(self):
+#        self.hide()
+#        StartWindow.show()
+
+
+
+    def OK(self):
+#        self.save()
+        self.close()
+#        StartWindow.show()
+
+
+
     ###########################################################################
     ##
     ###########################################################################
     def closeEvent(self, event):  ##(Class ConfigWindow)
+        self.save() #closing the window is equal to saving
+#        self.close()
+#        event.ignore() #do not close
+        StartWindow.show()
+
+
+
+
+
+    def save(self):
+#        print "save"
         if(self.ui.cOfflineMode.isChecked()==True):
-                data.OfflineMode=True
+            data.OfflineMode=True
         else:
             data.OfflineMode=False
         config.set('main', 'OfflineMode', str(data.OfflineMode))
 
         if(self.ui.cSilentProfile.isChecked()==True):
-                data.SilentProfile=True
+            data.SilentProfile=True
         else:
             data.SilentProfile=False
         config.set('main', 'SilentProfile', str(data.SilentProfile))
 
         if(self.ui.cStopAfterAlarm.isChecked()==True):
-                data.StopAfterAlarm=True
+            data.StopAfterAlarm=True
         else:
             data.StopAfterAlarm=False
         config.set('main', 'StopAfterAlarm', str(data.StopAfterAlarm))
@@ -1434,8 +1470,6 @@ class frmConfigWindow(QMainWindow):
         config.set('main', 'DelayStartTime', str(data.DelayStartTime))
         config.set('main', 'Yscale', str(data.Yscale))
 
-        self.close()
-        StartWindow.show()
 
 
     ###########################################################################
